@@ -42,12 +42,12 @@ class TokenValidator:
         self._public_key = None
         logger.info(f"{type(self).__name__} inited")
 
-    def validate_access_token(self, token: str, origin: str) -> JWTPayload:
+    async def validate_access_token(self, token: str, origin: str) -> JWTPayload:
         if token is None:
             raise InvalidTokenError("No access token")
 
         if self._public_key is None:
-            self._public_key = self.context.auth_server_connector.get_public_key()
+            self._public_key = await self.context.auth_server_connector.get_public_key()
 
         try:
             payload = jwt.decode(token, self._public_key, algorithms=[self._SIGNATURE_ALGORITHM])
